@@ -1,4 +1,5 @@
 """Logging module."""
+
 import logging
 from logging import handlers
 import sys
@@ -18,13 +19,15 @@ def getLogger(name: str = None) -> "logging.Logger":
     log: "logging.Logger" = logging.getLogger(name)
     log.setLevel(logging.DEBUG)
     format: "logging.Formatter" = logging.Formatter(
-        "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
+        "%(asctime)s - %(process)d - %(name)s - %(levelname)s - %(message)s"
     )
     stream_handler: "logging.StreamHandler" = logging.StreamHandler(sys.stdout)
     stream_handler.setFormatter(format)
     log.addHandler(stream_handler)
 
-    file_handler = handlers.RotatingFileHandler(log_file, maxBytes=(1048576 * 5), backupCount=7)
+    file_handler = handlers.RotatingFileHandler(
+        log_file, maxBytes=(1048576 * 5), backupCount=7
+    )
     file_handler.setFormatter(format)
     log.addHandler(file_handler)
 
